# PH-ADORB (WIP):
### A Python Library for calculating building ADORB costs.

> A.D.O.R.B. cost: Annualized De-carbonization Of Retrofitted Buildings cost - a “full-cost-accounted” 
annualized life-cycle cost metric for building projects. It includes the (annualized) direct costs of 
retrofit and maintenance, direct energy costs, a carbon cost for both operating and embodied/upfront 
greenhouse gas emissions, and a renewable-energy system-transition cost based on the required 
electrical service capacity.
[[Phius Revive 2024 Retrofit Standard for Buildings v24.1.00]](https://www.phius.org/phius-revive-2024-standard-document)

- - - 
The ADORB cost is used as part of the  [Phius-REVIVE](https://www.phius.org/phius-revive-2024) building retrofit program. [Phius Research Committee](https://github.com/Phius-ResearchComittee) has an example implementation of the ADORB calculation which can be found at:

[https://github.com/Phius-ResearchComittee/REVIVE](https://github.com/Phius-ResearchComittee/REVIVE/tree/main/REVIVE2024)

The PH-ADORB library is an adaptation of this original code into an object-oriented version. This library is a work-in-progress and should NOT be used for any Phius compliance analysis or reporting. 

## Note: 
*PH-Tools is in no way affiliated with Phius, and the library here is neither reviewed, nor approved by Phius for use in complying with the REVIVE program.*

## More Information:
For more information on the use of these tools, check out the the Passive House Tools website:
[https://www.PassiveHouseTools.com](https://www.PassiveHouseTools.com)


## Contact:
For questions about PH-ADORB, feel free to reach out at: PH_Tools@bldgtyp.com

### This library is for research and testing purposes only.

![Tests](https://github.com/PH-Tools/ph_adorb/actions/workflows/ci.yaml/badge.svg)
